@@ -6,10 +6,6 @@
 // notice may not be copied, modified, or distributed except
 // according to those terms.
 
-#[macro_use]
-extern crate clap;
-extern crate version_check;
-
 use clap::Shell;
 use std::fs;
 use std::io::{self, Write};
@@ -18,11 +14,11 @@ use std::process::exit;
 include!("src/app.rs");
 
 fn main() {
-    match version_check::is_min_version("1.29") {
+    match version_check::is_min_version("1.31") {
         Some((true, _)) => {}
         // rustc version too small or can't figure it out
         _ => {
-            writeln!(&mut io::stderr(), "'fd' requires rustc >= 1.29").unwrap();
+            writeln!(&mut io::stderr(), "'fd' requires rustc >= 1.31").unwrap();
             exit(1);
         }
     }
